#[repr(u32)]pub enum AVDevToAppMessageType {
AV_DEV_TO_APP_NONE = 1_313_820_229,
AV_DEV_TO_APP_CREATE_WINDOW_BUFFER = 1_111_708_229,
AV_DEV_TO_APP_PREPARE_WINDOW_BUFFER = 1_112_560_197,
AV_DEV_TO_APP_DISPLAY_WINDOW_BUFFER = 1_111_771_475,
AV_DEV_TO_APP_DESTROY_WINDOW_BUFFER = 1_111_770_451,
AV_DEV_TO_APP_BUFFER_OVERFLOW = 1_112_491_596,
AV_DEV_TO_APP_BUFFER_UNDERFLOW = 1_112_884_812,
AV_DEV_TO_APP_BUFFER_READABLE = 1_112_687_648,
AV_DEV_TO_APP_BUFFER_WRITABLE = 1_113_018_912,
AV_DEV_TO_APP_MUTE_STATE_CHANGED = 1_129_141_588,
AV_DEV_TO_APP_VOLUME_LEVEL_CHANGED = 1_129_729_868,
}Expand description
Message types used by avdevice_dev_to_app_control_message().
Variants
AV_DEV_TO_APP_NONE = 1_313_820_229
Dummy message.
AV_DEV_TO_APP_CREATE_WINDOW_BUFFER = 1_111_708_229
Create window buffer message.
Device requests to create a window buffer. Exact meaning is device- and application-dependent. Message is sent before rendering first frame and all one-shot initializations should be done here. Application is allowed to ignore preferred window buffer size.
@note: Application is obligated to inform about window buffer size with AV_APP_TO_DEV_WINDOW_SIZE message.
data: AVDeviceRect: preferred size of the window buffer. NULL: no preferred size of the window buffer.
AV_DEV_TO_APP_PREPARE_WINDOW_BUFFER = 1_112_560_197
Prepare window buffer message.
Device requests to prepare a window buffer for rendering. Exact meaning is device- and application-dependent. Message is sent before rendering of each frame.
data: NULL.
AV_DEV_TO_APP_DISPLAY_WINDOW_BUFFER = 1_111_771_475
Display window buffer message.
Device requests to display a window buffer. Message is sent when new frame is ready to be displayed. Usually buffers need to be swapped in handler of this message.
data: NULL.
AV_DEV_TO_APP_DESTROY_WINDOW_BUFFER = 1_111_770_451
Destroy window buffer message.
Device requests to destroy a window buffer. Message is sent when device is about to be destroyed and window buffer is not required anymore.
data: NULL.
AV_DEV_TO_APP_BUFFER_OVERFLOW = 1_112_491_596
Buffer fullness status messages.
Device signals buffer overflow/underflow.
data: NULL.
AV_DEV_TO_APP_BUFFER_UNDERFLOW = 1_112_884_812
Buffer fullness status messages.
Device signals buffer overflow/underflow.
data: NULL.
AV_DEV_TO_APP_BUFFER_READABLE = 1_112_687_648
Buffer readable/writable.
Device informs that buffer is readable/writable. When possible, device informs how many bytes can be read/write.
@warning Device may not inform when number of bytes than can be read/write changes.
data: int64_t: amount of bytes available to read/write. NULL: amount of bytes available to read/write is not known.
AV_DEV_TO_APP_BUFFER_WRITABLE = 1_113_018_912
Buffer readable/writable.
Device informs that buffer is readable/writable. When possible, device informs how many bytes can be read/write.
@warning Device may not inform when number of bytes than can be read/write changes.
data: int64_t: amount of bytes available to read/write. NULL: amount of bytes available to read/write is not known.
AV_DEV_TO_APP_MUTE_STATE_CHANGED = 1_129_141_588
Mute state change message.
Device informs that mute state has changed.
data: int: 0 for not muted state, non-zero for muted state.
AV_DEV_TO_APP_VOLUME_LEVEL_CHANGED = 1_129_729_868
Volume level change message.
Device informs that volume level has changed.
data: double: new volume with range of 0.0 - 1.0.