Function ffmpeg_sys_fframes::av_codec_next
source · pub unsafe extern "C" fn av_codec_next(
c: *const AVCodec,
) -> *mut AVCodecExpand description
If c is NULL, returns the first registered codec, if c is non-NULL, returns the next registered codec after c, or NULL if c is the last one.