Function ffmpeg_sys_fframes::sws_allocVec
source · pub unsafe extern "C" fn sws_allocVec(length: c_int) -> *mut SwsVectorExpand description
Allocate and return an uninitialized vector with length coefficients.
pub unsafe extern "C" fn sws_allocVec(length: c_int) -> *mut SwsVectorAllocate and return an uninitialized vector with length coefficients.