#[repr(C)]pub struct AVBSFContext {
pub av_class: *const AVClass,
pub filter: *const AVBitStreamFilter,
pub internal: *mut AVBSFInternal,
pub priv_data: *mut c_void,
pub par_in: *mut AVCodecParameters,
pub par_out: *mut AVCodecParameters,
pub time_base_in: AVRational,
pub time_base_out: AVRational,
}Expand description
The bitstream filter state.
This struct must be allocated with av_bsf_alloc() and freed with av_bsf_free().
The fields in the struct will only be changed (by the caller or by the filter) as described in their documentation, and are to be considered immutable otherwise.
Fields
av_class: *const AVClassA class for logging and AVOptions
filter: *const AVBitStreamFilterThe bitstream filter this context is an instance of.
internal: *mut AVBSFInternalOpaque libavcodec internal data. Must not be touched by the caller in any way.
priv_data: *mut c_voidOpaque filter-specific private data. If filter->priv_class is non-NULL, this is an AVOptions-enabled struct.
par_in: *mut AVCodecParametersParameters of the input stream. This field is allocated in av_bsf_alloc(), it needs to be filled by the caller before av_bsf_init().
par_out: *mut AVCodecParametersParameters of the output stream. This field is allocated in av_bsf_alloc(), it is set by the filter in av_bsf_init().
time_base_in: AVRationalThe timebase used for the timestamps of the input packets. Set by the caller before av_bsf_init().
time_base_out: AVRationalThe timebase used for the timestamps of the output packets. Set by the filter in av_bsf_init().