#[repr(C)]pub struct AVBufferSrcParameters {
pub format: c_int,
pub time_base: AVRational,
pub width: c_int,
pub height: c_int,
pub sample_aspect_ratio: AVRational,
pub frame_rate: AVRational,
pub hw_frames_ctx: *mut AVBufferRef,
pub sample_rate: c_int,
pub channel_layout: u64,
}Expand description
This structure contains the parameters describing the frames that will be passed to this filter.
It should be allocated with av_buffersrc_parameters_alloc() and freed with av_free(). All the allocated fields in it remain owned by the caller.
Fields
format: c_intvideo: the pixel format, value corresponds to enum AVPixelFormat audio: the sample format, value corresponds to enum AVSampleFormat
time_base: AVRationalThe timebase to be used for the timestamps on the input frames.
width: c_intVideo only, the display dimensions of the input frames.
height: c_intVideo only, the display dimensions of the input frames.
sample_aspect_ratio: AVRationalVideo only, the sample (pixel) aspect ratio.
frame_rate: AVRationalVideo only, the frame rate of the input video. This field must only be set to a non-zero value if input stream has a known constant framerate and should be left at its initial value if the framerate is variable or unknown.
hw_frames_ctx: *mut AVBufferRefVideo with a hwaccel pixel format only. This should be a reference to an AVHWFramesContext instance describing the input frames.
sample_rate: c_intAudio only, the audio sampling rate in samples per second.
channel_layout: u64Audio only, the audio channel layout