#[repr(C)]pub struct AVDRMFrameDescriptor {
pub nb_objects: c_int,
pub objects: [AVDRMObjectDescriptor; 4],
pub nb_layers: c_int,
pub layers: [AVDRMLayerDescriptor; 4],
}Expand description
DRM frame descriptor.
This is used as the data pointer for AV_PIX_FMT_DRM_PRIME frames. It is also used by user-allocated frame pools - allocating in AVHWFramesContext.pool must return AVBufferRefs which contain an object of this type.
The fields of this structure should be set such it can be imported directly by EGL using the EGL_EXT_image_dma_buf_import and EGL_EXT_image_dma_buf_import_modifiers extensions. (Note that the exact layout of a particular format may vary between platforms - we only specify that the same platform should be able to import it.)
The total number of planes must not exceed AV_DRM_MAX_PLANES, and the order of the planes by increasing layer index followed by increasing plane index must be the same as the order which would be used for the data pointers in the equivalent software format.
Fields
nb_objects: c_intNumber of DRM objects making up this frame.
objects: [AVDRMObjectDescriptor; 4]Array of objects making up the frame.
nb_layers: c_intNumber of layers in the frame.
layers: [AVDRMLayerDescriptor; 4]Array of layers in the frame.